@@ -113,6 +113,8 @@ class AlbumArt(BaseArt, TagReader):
             @param album as Album
             @return [paths]
         """
+        if album.is_youtube:
+            return []
         all_paths = [os.path.join(album.path, f) for f in os.listdir(
                                                                 album.path)]
         paths = []
@@ -155,12 +157,12 @@ class AlbumArt(BaseArt, TagReader):
                 if pixbuf is None and album.tracks:
                     try:
                         pixbuf = self.pixbuf_from_tags(
-                                    album.tracks[0].path, size)
+                                    album.tracks[0].uri, size)
                     except Exception as e:
                         pass
 
                 # Use folder artwork
-                if pixbuf is None:
+                if pixbuf is None and album.path != "":
                     path = self.get_first_album_artwork(album)
                     # Look in album folder
                     if path is not None:
@@ -195,7 +197,7 @@ class AlbumArt(BaseArt, TagReader):
             @return cairo surface
         """
         size *= scale
-        pixbuf = self.pixbuf_from_tags(GLib.filename_from_uri(uri)[0], size)
+        pixbuf = self.pixbuf_from_tags(uri, size)
         if pixbuf is not None:
             surface = Gdk.cairo_surface_create_from_pixbuf(pixbuf, scale, None)
             del pixbuf
@@ -214,6 +216,7 @@ class AlbumArt(BaseArt, TagReader):
             save_to_tags = Lp().settings.get_value('artwork-tags') and\
                 which("kid3-cli") is not None
             album = Album(album_id)
+
             path_count = Lp().albums.get_path_count(album.path)
             filename = self.__get_album_cache_name(album) + ".jpg"
             if save_to_tags:
@@ -222,13 +225,13 @@ class AlbumArt(BaseArt, TagReader):
                 t.daemon = True
                 t.start()
 
+            if album.path == "" or is_readonly(album.path):
+                artpath = os.path.join(self._STORE_PATH, filename)
             # Many albums with same path, suffix with artist_album name
-            if path_count > 1:
+            elif path_count > 1:
                 artpath = os.path.join(album.path, filename)
                 if os.path.exists(os.path.join(album.path, self.__favorite)):
                     os.remove(os.path.join(album.path, self.__favorite))
-            elif is_readonly(album.path):
-                artpath = os.path.join(self._STORE_PATH, filename)
             else:
                 artpath = os.path.join(album.path, self.__favorite)
             # Update cover file if exists event if we have written to tags
@@ -261,12 +264,15 @@ class AlbumArt(BaseArt, TagReader):
         """
         try:
             for artwork in self.get_album_artworks(album):
-                os.remove(os.path.join(album.path, artwork))
+                path = os.path.join(album.path, artwork)
+                f = Gio.File.new_for_path(path)
+                f.trash()
             if Lp().settings.get_value('artwork-tags') and\
                     which("kid3-cli") is not None:
                 argv = ["kid3-cli", "-c", "select all", "-c",
                         "set picture:'' ''"]
-                for path in Lp().albums.get_track_paths(album.id, [], []):
+                for uri in Lp().albums.get_track_uris(album.id, [], []):
+                    path = GLib.filename_from_uri(uri)[0]
                     argv.append(path)
                 argv.append(None)
                 GLib.spawn_sync(None, argv, None,
@@ -287,15 +293,17 @@ class AlbumArt(BaseArt, TagReader):
         except Exception as e:
             print("Art::clean_album_cache(): ", e, filename)
 
-    def pixbuf_from_tags(self, filepath, size):
+    def pixbuf_from_tags(self, uri, size):
         """
             Return cover from tags
             @param filepath as str
             @param size as int
         """
         pixbuf = None
+        if not uri.startswith('file:'):
+            return
         try:
-            info = self.get_info(filepath)
+            info = self.get_info(uri)
             exist = False
             if info is not None:
                 (exist, sample) = info.get_tags().get_sample_index('image', 0)
@@ -338,7 +346,8 @@ class AlbumArt(BaseArt, TagReader):
         if os.path.exists("/tmp/lollypop_cover_tags.jpg"):
             argv = ["kid3-cli", "-c", "select all", "-c",
                     "set picture:'/tmp/lollypop_cover_tags.jpg' ''"]
-            for path in Lp().albums.get_track_paths(album.id, [], []):
+            for uri in Lp().albums.get_track_uris(album.id, [], []):
+                path = GLib.filename_from_uri(uri)[0]
                 argv.append(path)
             argv.append(None)
             GLib.spawn_sync(None, argv, None,
