@@ -31,9 +31,11 @@ class CollectionScanner(GObject.GObject, TagReader):
     """
     __gsignals__ = {
         'scan-finished': (GObject.SignalFlags.RUN_FIRST, None, ()),
-        'artist-added': (GObject.SignalFlags.RUN_FIRST, None, (int, int)),
-        'genre-added': (GObject.SignalFlags.RUN_FIRST, None, (int,)),
-        'album-update': (GObject.SignalFlags.RUN_FIRST, None, (int,))
+        'artist-updated': (GObject.SignalFlags.RUN_FIRST, None, (int,
+                                                                 int,
+                                                                 bool)),
+        'genre-updated': (GObject.SignalFlags.RUN_FIRST, None, (int, bool)),
+        'album-updated': (GObject.SignalFlags.RUN_FIRST, None, (int,))
     }
 
     def __init__(self):
@@ -49,20 +51,19 @@ class CollectionScanner(GObject.GObject, TagReader):
             self.__inotify = Inotify()
         else:
             self.__inotify = None
-        self.__progress = None
 
-    def update(self, progress):
+    def update(self):
         """
             Update database
-            @param progress as Gtk.Scale
         """
         if not self.is_locked():
-            progress.show()
-            self.__progress = progress
             paths = Lp().settings.get_music_paths()
             if not paths:
                 return
 
+            Lp().window.progress.add(self)
+            Lp().window.progress.set_fraction(0.0, self)
+
             if Lp().notify is not None:
                 Lp().notify.send(_("Your music is updating"))
             self.__thread = Thread(target=self.__scan, args=(paths,))
@@ -80,10 +81,6 @@ class CollectionScanner(GObject.GObject, TagReader):
             Stop scan
         """
         self.__thread = None
-        if self.__progress is not None:
-            self.__progress.hide()
-            self.__progress.set_fraction(0.0)
-            self.__progress = None
 
 #######################
 # PRIVATE             #
@@ -96,41 +93,46 @@ class CollectionScanner(GObject.GObject, TagReader):
         """
         tracks = []
         track_dirs = list(paths)
-        count = 0
         for path in paths:
+            tracks_for_path = []
             for root, dirs, files in os.walk(path, followlinks=True):
                 # Add dirs
                 for d in dirs:
                     track_dirs.append(os.path.join(root, d))
                 # Add files
                 for name in files:
-                    filepath = os.path.join(root, name)
+                    path = os.path.join(root, name)
+                    uri = GLib.filename_to_uri(path)
                     try:
-                        f = Gio.File.new_for_path(filepath)
+                        f = Gio.File.new_for_uri(uri)
                         if is_pls(f):
                             pass
                         elif is_audio(f):
-                            tracks.append(filepath)
-                            count += 1
+                            tracks_for_path.append(uri)
                         else:
-                            debug("%s not detected as a music file" % filepath)
+                            debug("%s not detected as a music file" % uri)
                     except Exception as e:
                         print("CollectionScanner::__get_objects_for_paths: %s"
                               % e)
-        return (tracks, track_dirs, count)
+            # If a path is empty, return nothing
+            # Ensure user is not doing something bad
+            if not tracks_for_path:
+                return ([], [])
+            tracks += tracks_for_path
+        return (tracks, track_dirs)
 
     def __update_progress(self, current, total):
         """
             Update progress bar status
             @param scanned items as int, total items as int
         """
-        if self.__progress is not None:
-            self.__progress.set_fraction(current/total)
+        Lp().window.progress.set_fraction(current / total, self)
 
     def __finish(self):
         """
             Notify from main thread when scan finished
         """
+        Lp().window.progress.set_fraction(1.0, self)
         self.stop()
         self.emit("scan-finished")
         if Lp().settings.get_value('artist-artwork'):
@@ -146,12 +148,16 @@ class CollectionScanner(GObject.GObject, TagReader):
         if self.__history is None:
             self.__history = History()
         mtimes = Lp().tracks.get_mtimes()
-        orig_tracks = Lp().tracks.get_paths()
+        orig_tracks = Lp().tracks.get_uris()
         was_empty = len(orig_tracks) == 0
 
-        (new_tracks, new_dirs, count) = self.__get_objects_for_paths(paths)
-        count += len(orig_tracks)
-
+        (new_tracks, new_dirs) = self.__get_objects_for_paths(paths)
+        if not new_tracks:
+            if Lp().notify is not None:
+                Lp().notify.send(_("Lollypop is detecting an empty folder."),
+                                 _("Check your music settings."))
+            return
+        count = len(new_tracks) + len(orig_tracks)
         # Add monitors on dirs
         if self.__inotify is not None:
             for d in new_dirs:
@@ -159,64 +165,67 @@ class CollectionScanner(GObject.GObject, TagReader):
 
         with SqlCursor(Lp().db) as sql:
             i = 0
-            for filepath in new_tracks:
+            for uri in new_tracks:
                 if self.__thread is None:
                     return
                 GLib.idle_add(self.__update_progress, i, count)
                 try:
+                    f = Gio.File.new_for_uri(uri)
+                    info = f.query_info('time::modified',
+                                        Gio.FileQueryInfoFlags.NONE,
+                                        None)
+                    mtime = int(info.get_attribute_as_string('time::modified'))
                     # If songs exists and mtime unchanged, continue,
                     # else rescan
-                    if filepath in orig_tracks:
-                        orig_tracks.remove(filepath)
+                    if uri in orig_tracks:
+                        orig_tracks.remove(uri)
                         i += 1
-                        mtime = int(os.path.getmtime(filepath))
-                        if mtime <= mtimes[filepath]:
+                        if mtime <= mtimes[uri]:
                             i += 1
                             continue
                         else:
-                            self.__del_from_db(filepath)
-                    info = self.get_info(filepath)
+                            self.__del_from_db(uri)
+                    info = self.get_info(uri)
                     # On first scan, use modification time
                     # Else, use current time
-                    if was_empty:
-                        mtime = int(os.path.getmtime(filepath))
-                    else:
+                    if not was_empty:
                         mtime = int(time())
-                    debug("Adding file: %s" % filepath)
-                    self.__add2db(filepath, info, mtime)
+                    debug("Adding file: %s" % uri)
+                    self.__add2db(uri, info, mtime)
                 except GLib.GError as e:
-                    print(e, filepath)
+                    print(e, uri)
                     if e.message != gst_message:
                         gst_message = e.message
                         if Lp().notify is not None:
                             Lp().notify.send(gst_message)
-                except:
-                    pass
+                except Exception as e:
+                    print("CollectionScanner::__scan()", e)
                 i += 1
 
             # Clean deleted files
-            for filepath in orig_tracks:
+            for uri in orig_tracks:
                 i += 1
                 GLib.idle_add(self.__update_progress, i, count)
-                self.__del_from_db(filepath)
+                if uri.startswith('file:'):
+                    self.__del_from_db(uri)
 
             sql.commit()
         GLib.idle_add(self.__finish)
         del self.__history
         self.__history = None
 
-    def __add2db(self, filepath, info, mtime):
+    def __add2db(self, uri, info, mtime):
         """
             Add new file to db with informations
-            @param filepath as string
+            @param uri as string
             @param info as GstPbutils.DiscovererInfo
             @param mtime as int
             @return track id as int
         """
         debug("CollectionScanner::add2db(): Read tags")
+        path = GLib.filename_from_uri(uri)[0]
         tags = info.get_tags()
-
-        title = self.get_title(tags, filepath)
+        title = self.get_title(tags, path)
         artists = self.get_artists(tags)
         composers = self.get_composers(tags)
         performers = self.get_performers(tags)
@@ -227,10 +236,10 @@ class CollectionScanner(GObject.GObject, TagReader):
         genres = self.get_genres(tags)
         discnumber = self.get_discnumber(tags)
         discname = self.get_discname(tags)
-        tracknumber = self.get_tracknumber(tags, GLib.basename(filepath))
+        tracknumber = self.get_tracknumber(tags, GLib.basename(path))
         year = self.get_year(tags)
         duration = int(info.get_duration()/1000000000)
-        name = GLib.path_get_basename(filepath)
+        name = GLib.path_get_basename(path)
 
         # If no artists tag, use album artist
         if artists == '':
@@ -266,13 +275,13 @@ class CollectionScanner(GObject.GObject, TagReader):
         debug("CollectionScanner::add2db(): Add album: "
               "%s, %s" % (album_name, album_artist_ids))
         (album_id, new_album) = self.add_album(album_name, album_artist_ids,
-                                               filepath, album_pop, amtime)
+                                               path, album_pop, amtime)
 
         (genre_ids, new_genre_ids) = self.add_genres(genres, album_id)
 
         # Add track to db
         debug("CollectionScanner::add2db(): Add track")
-        track_id = Lp().tracks.add(title, filepath, duration,
+        track_id = Lp().tracks.add(title, uri, duration,
                                    tracknumber, discnumber, discname,
                                    album_id, year, track_pop,
                                    track_ltime, mtime)
@@ -285,18 +294,20 @@ class CollectionScanner(GObject.GObject, TagReader):
             with SqlCursor(Lp().db) as sql:
                 sql.commit()
             for genre_id in new_genre_ids:
-                GLib.idle_add(self.emit, 'genre-added', genre_id)
+                GLib.idle_add(self.emit, 'genre-updated', genre_id, True)
             for artist_id in new_artist_ids:
-                GLib.idle_add(self.emit, 'artist-added', artist_id, album_id)
+                GLib.idle_add(self.emit, 'artist-updated',
+                              artist_id, album_id, True)
         return track_id
 
-    def __del_from_db(self, filepath):
+    def __del_from_db(self, uri):
         """
             Delete track from db
-            @param filepath as str
+            @param uri as str
         """
-        name = GLib.path_get_basename(filepath)
-        track_id = Lp().tracks.get_id_by_path(filepath)
+        path = GLib.filename_from_uri(uri)[0]
+        name = GLib.path_get_basename(path)
+        track_id = Lp().tracks.get_id_by_uri(uri)
         album_id = Lp().tracks.get_album_id(track_id)
         genre_ids = Lp().tracks.get_genre_ids(track_id)
         album_artist_ids = Lp().albums.get_artist_ids(album_id)
@@ -314,8 +325,13 @@ class CollectionScanner(GObject.GObject, TagReader):
         if modified:
             with SqlCursor(Lp().db) as sql:
                 sql.commit()
-            GLib.idle_add(self.emit, 'album-update', album_id)
+            GLib.idle_add(self.emit, 'album-updated', album_id)
         for artist_id in album_artist_ids + artist_ids:
-            Lp().artists.clean(artist_id)
+            ret = Lp().artists.clean(artist_id)
+            if ret:
+                GLib.idle_add(self.emit, 'artist-updated',
+                              artist_id, album_id, False)
         for genre_id in genre_ids:
-            Lp().genres.clean(genre_id)
+            ret = Lp().genres.clean(genre_id)
+            if ret:
+                GLib.idle_add(self.emit, 'genre-updated', genre_id, False)
