@@ -21,6 +21,7 @@ from lollypop.view_container import ViewContainer
 from lollypop.view_albums import AlbumsView
 from lollypop.view_artist import ArtistView
 from lollypop.view_radios import RadiosView
+from lollypop.progressbar import ProgressBar
 from lollypop.view_playlists import PlaylistsView
 from lollypop.view_playlists import PlaylistsManageView, PlaylistEditView
 from lollypop.view_device import DeviceView, DeviceLocked, DeviceMigration
@@ -77,9 +78,7 @@ class Container:
             Lp().scanner.stop()
             GLib.timeout_add(250, self.update_db)
         else:
-            # Something (device manager) is using progress bar
-            if not self.__progress.is_visible():
-                Lp().scanner.update(self.__progress)
+            Lp().scanner.update()
 
     def get_genre_id(self):
         """
@@ -260,6 +259,22 @@ class Container:
             d.make_directory_with_parents(None)
         self.__devices[self.__devices_index] = dev
 
+    def show_artists_albums(self, artist_ids):
+        """
+            Show albums from artists
+        """
+        self.__update_view_artists([], artist_ids)
+        GLib.idle_add(self.__list_two.hide)
+        GLib.idle_add(self.__list_one.select_ids, [])
+
+    @property
+    def progress(self):
+        """
+            Progress bar
+            @return ProgressBar
+        """
+        return self.__progress
+
 ############
 # Private  #
 ############
@@ -272,7 +287,7 @@ class Container:
             self.__progress.pulse()
             return True
         else:
-            self.__progress.set_fraction(0.0)
+            self.__progress.set_fraction(0.0, self)
             return False
 
     def __setup_view(self):
@@ -294,7 +309,7 @@ class Container:
         self.__list_one.connect('populated', self.__on_list_populated)
         self.__list_two.connect('item-selected', self.__on_list_two_selected)
 
-        self.__progress = Gtk.ProgressBar()
+        self.__progress = ProgressBar()
         self.__progress.set_property('hexpand', True)
 
         vgrid.add(self.__stack)
@@ -332,22 +347,27 @@ class Container:
                     list_two_ids.append(i)
         return (list_one_ids, list_two_ids)
 
-    def __add_genre(self, scanner, genre_id):
+    def __on_genre_updated(self, scanner, genre_id, add):
         """
             Add genre to genre list
             @param scanner as CollectionScanner
             @param genre id as int
+            @param add as bool
         """
         if self.__show_genres:
-            genre_name = Lp().genres.get_name(genre_id)
-            self.__list_one.add_value((genre_id, genre_name))
+            if add:
+                genre_name = Lp().genres.get_name(genre_id)
+                self.__list_one.add_value((genre_id, genre_name))
+            else:
+                self.__list_one.remove_value(genre_id)
 
-    def __add_artist(self, scanner, artist_id, album_id):
+    def __on_artist_updated(self, scanner, artist_id, album_id, add):
         """
             Add artist to artist list
             @param scanner as CollectionScanner
             @param artist id as int
             @param album id as int
+            @param add as bool
         """
         artist_name = Lp().artists.get_name(artist_id)
         if self.__show_genres:
@@ -355,9 +375,15 @@ class Container:
             genre_ids.append(Type.ALL)
             for i in self.__list_one.get_selected_ids():
                 if i in genre_ids:
-                    self.__list_two.add_value((artist_id, artist_name))
+                    if add:
+                        self.__list_two.add_value((artist_id, artist_name))
+                    else:
+                        self.__list_two.remove_value(artist_id)
         else:
-            self.__list_one.add_value((artist_id, artist_name))
+            if add:
+                self.__list_one.add_value((artist_id, artist_name))
+            else:
+                self.__list_one.remove_value(artist_id)
 
     def __setup_scanner(self):
         """
@@ -365,8 +391,8 @@ class Container:
             @return True if hard scan is running
         """
         Lp().scanner.connect('scan-finished', self.on_scan_finished)
-        Lp().scanner.connect('genre-added', self.__add_genre)
-        Lp().scanner.connect('artist-added', self.__add_artist)
+        Lp().scanner.connect('genre-updated', self.__on_genre_updated)
+        Lp().scanner.connect('artist-updated', self.__on_artist_updated)
 
     def __update_playlists(self, playlists, playlist_id):
         """
@@ -381,7 +407,7 @@ class Container:
                                              Lp().playlists.get_name(
                                                                   playlist_id))
             else:
-                self.__list_two.remove(playlist_id)
+                self.__list_two.remove_value(playlist_id)
 
     def __update_lists(self, updater=None):
         """
@@ -424,6 +450,8 @@ class Container:
         items.append((Type.RANDOMS, _("Random albums")))
         items.append((Type.PLAYLISTS, _("Playlists")))
         items.append((Type.RADIOS, _("Radios")))
+        if Lp().settings.get_value('network-search'):
+            items.append((Type.CHARTS, _("The charts")))
         if self.__show_genres:
             items.append((Type.ALL, _("All artists")))
         else:
@@ -527,7 +555,7 @@ class Container:
                         child = DeviceMigration()
                         self.__stack.add(child)
                 if child is None:
-                    child = DeviceView(device, self.__progress)
+                    child = DeviceView(device)
                     self.__stack.add_named(child, device.uri)
             else:
                 child = DeviceLocked()
@@ -674,7 +702,7 @@ class Container:
         uri = mount.get_default_location().get_uri()
         for dev in self.__devices.values():
             if dev.uri == uri:
-                self.__list_one.remove(dev.id)
+                self.__list_one.remove_value(dev.id)
                 child = self.__stack.get_child_by_name(uri)
                 if child is not None:
                     child.destroy()
@@ -701,7 +729,8 @@ class Container:
                 self.__update_view_device(selected_ids[0])
         elif selected_ids[0] in [Type.POPULARS,
                                  Type.RECENTS,
-                                 Type.RANDOMS]:
+                                 Type.RANDOMS,
+                                 Type.CHARTS]:
             self.__list_two.hide()
             self.__update_view_albums(selected_ids, [])
         elif selected_ids[0] == Type.RADIOS:
