@@ -140,6 +140,9 @@ class ProgressController:
         self.__seeking = False
         # Update pogress position
         self.__timeout_id = None
+        # Show volume control
+        self._show_volume_control = False
+        Lp().player.connect('duration-changed', self.__on_duration_changed)
 
     def on_current_changed(self, player):
         """
@@ -147,15 +150,19 @@ class ProgressController:
             @param player as Player
         """
         self._progress.clear_marks()
-        if player.current_track.id != Type.RADIOS:
-            self._progress.set_sensitive(player.current_track.id is not None)
+        if player.current_track.id is None:
+            self._progress.set_sensitive(False)
+            self._total_time_label.set_text("")
+            return
+
         self._progress.set_value(0.0)
         self._timelabel.set_text("0:00")
         if player.current_track.id == Type.RADIOS:
             self._progress.set_sensitive(False)
-            self._total_time_label.set_text('')
+            self._total_time_label.set_text("")
             self._progress.set_range(0.0, 0.0)
         else:
+            self._progress.set_sensitive(True)
             self._progress.set_range(0.0, player.current_track.duration * 60)
             self._total_time_label.set_text(
                 seconds_to_string(player.current_track.duration))
@@ -178,12 +185,42 @@ class ProgressController:
 #######################
 # PROTECTED           #
 #######################
+    def _update_state(self):
+        """
+            Update controller state volume vs progress
+        """
+        if self._show_volume_control:
+            self._timelabel.set_text(_("Volume"))
+            self._progress.set_range(0.0, 1.0)
+            self._progress.set_sensitive(True)
+            self._update_position()
+        else:
+            self.on_current_changed(Lp().player)
+            if Lp().player.current_track.id is None:
+                self._timelabel.set_text("")
+                self._progress.set_value(0.0)
+                self._progress.set_range(0.0, 0.0)
+                self._progress.set_sensitive(False)
+            else:
+                self._update_position()
+
+    def _on_value_changed(self, scale):
+        """
+            Adjust volume
+        """
+        if not self._show_volume_control:
+            return
+        Lp().player.set_volume(scale.get_value())
+        self._update_position(scale.get_value())
+
     def _on_progress_press_button(self, scale, event):
         """
             On press, mark player as seeking
             @param scale as Gtk.Scale
             @param event as Gdk.Event
         """
+        if self._show_volume_control:
+            return
         if Lp().player.locked:
             return True
         self.__seeking = True
@@ -195,6 +232,8 @@ class ProgressController:
             @param scale as Gtk.Scale
             @param event as Gdk.Event
         """
+        if self._show_volume_control:
+            return
         value = scale.get_value()
         Lp().player.seek(value/60)
         self.__seeking = False
@@ -207,25 +246,44 @@ class ProgressController:
             @param event as Gdk.Event
         """
         (smooth, x, y) = event.get_scroll_deltas()
-        if smooth and Lp().player.is_playing():
-            position = Lp().player.position
-            if y > 0:
-                seek = position/1000000/60-5
-            else:
-                seek = position/1000000/60+5
-            if seek < 0:
-                seek = 0
-            if seek > Lp().player.current_track.duration:
-                seek = Lp().player.current_track.duration - 2
-            Lp().player.seek(seek)
-            self._update_position(seek*60)
+        if smooth:
+            if self._show_volume_control:
+                volume = Lp().player.volume
+                if y > 0:
+                    volume -= 0.1
+                else:
+                    volume += 0.1
+                if volume < 0:
+                    volume = 0.0
+                elif volume > 1:
+                    volume = 1.0
+                Lp().player.set_volume(volume)
+                self._update_position(volume)
+            elif Lp().player.is_playing():
+                position = Lp().player.position
+                if y > 0:
+                    seek = position/1000000/60-5
+                else:
+                    seek = position/1000000/60+5
+                if seek < 0:
+                    seek = 0
+                if seek > Lp().player.current_track.duration:
+                    seek = Lp().player.current_track.duration - 2
+                Lp().player.seek(seek)
+                self._update_position(seek*60)
 
     def _update_position(self, value=None):
         """
             Update progress bar position
             @param value as int
         """
-        if not self.__seeking:
+        if self._show_volume_control:
+            if value is None:
+                value = Lp().player.volume
+            self._progress.set_value(value)
+            volume = str(int(value * 100)) + " %"
+            self._total_time_label.set_text(volume)
+        elif not self.__seeking:
             if value is None and Lp().player.get_status() != Gst.State.PAUSED:
                 value = Lp().player.position/1000000
             if value is not None:
@@ -233,6 +291,20 @@ class ProgressController:
                 self._timelabel.set_text(seconds_to_string(value/60))
         return True
 
+#######################
+# PRIVATE             #
+#######################
+    def __on_duration_changed(self, player, track_id):
+        """
+            Update duration
+            @param player as Player
+            @param track id as int
+        """
+        if track_id == player.current_track.id:
+            self._progress.set_range(0.0, player.current_track.duration * 60)
+            self._total_time_label.set_text(
+                    seconds_to_string(player.current_track.duration))
+
 
 class InfosController:
     """
@@ -244,6 +316,7 @@ class InfosController:
             Init controller
         """
         self._infobox = None
+        self._spinner = None
         self._artsize = artsize
 
     def on_current_changed(self, player):
@@ -259,8 +332,15 @@ class InfosController:
             self._cover.hide()
             return
 
+        # Stop spinner if running
+        if self._spinner is not None:
+            self._spinner.hide()
+            self._spinner.stop()
+
         self._artist_label.set_text(", ".join(player.current_track.artists))
+        self._artist_label.show()
         self._title_label.set_text(player.current_track.title)
+        self._title_label.show()
 
         if player.current_track.id == Type.RADIOS:
             art = Lp().art.get_radio_artwork(
