@@ -14,12 +14,12 @@ from gi.repository import GLib
 
 import sqlite3
 import os
-import unicodedata
 
 from lollypop.define import Lp
 from lollypop.database_upgrade import DatabaseUpgrade
 from lollypop.sqlcursor import SqlCursor
 from lollypop.localized import LocalizedCollation
+from lollypop.utils import noaccents
 
 
 class Database:
@@ -55,7 +55,7 @@ class Database:
                                                 genre_id INT NOT NULL)'''
     __create_tracks = '''CREATE TABLE tracks (id INTEGER PRIMARY KEY,
                                               name TEXT NOT NULL,
-                                              filepath TEXT NOT NULL,
+                                              uri TEXT NOT NULL,
                                               duration INT,
                                               tracknumber INT,
                                               discnumber INT,
@@ -64,7 +64,9 @@ class Database:
                                               year INT,
                                               popularity INT NOT NULL,
                                               ltime INT NOT NULL,
-                                              mtime INT NOT NULL)'''
+                                              mtime INT NOT NULL,
+                                              persistent INT NOT NULL
+                                              DEFAULT 1)'''
     __create_track_artists = '''CREATE TABLE track_artists (
                                                 track_id INT NOT NULL,
                                                 artist_id INT NOT NULL)'''
@@ -122,19 +124,31 @@ class Database:
         try:
             c = sqlite3.connect(self.DB_PATH, 600.0)
             c.create_collation('LOCALIZED', LocalizedCollation())
-            c.create_function("noaccents", 1, self.__noaccents)
+            c.create_function("noaccents", 1, noaccents)
             return c
         except:
             exit(-1)
 
+    def del_tracks(self, track_ids):
+        """
+            Delete tracks from db
+            @param track_ids as [int]
+        """
+        with SqlCursor(Lp().db) as sql:
+            for track_id in track_ids:
+                album_id = Lp().tracks.get_album_id(track_id)
+                genre_ids = Lp().tracks.get_genre_ids(track_id)
+                album_artist_ids = Lp().albums.get_artist_ids(album_id)
+                artist_ids = Lp().tracks.get_artist_ids(track_id)
+                Lp().tracks.remove(track_id)
+                Lp().tracks.clean(track_id)
+                Lp().albums.clean(album_id)
+                for artist_id in album_artist_ids + artist_ids:
+                    Lp().artists.clean(artist_id)
+                for genre_id in genre_ids:
+                    Lp().genres.clean(genre_id)
+            sql.commit()
+
 #######################
 # PRIVATE             #
 #######################
-    def __noaccents(self, string):
-        """
-            Return string without accents
-            @param string as str
-            @return str
-        """
-        nfkd_form = unicodedata.normalize('NFKD', string)
-        return u"".join([c for c in nfkd_form if not unicodedata.combining(c)])
