@@ -10,13 +10,15 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
+from gi.repository import GLib
+
 from gettext import gettext as _
 import os
 import itertools
 
 from lollypop.sqlcursor import SqlCursor
 from lollypop.define import Lp, Type, OrderBy
-from lollypop.utils import remove_static_genres
+from lollypop.utils import remove_static_genres, noaccents
 
 
 class AlbumsDatabase:
@@ -81,6 +83,16 @@ class AlbumsDatabase:
                             "album_genres (album_id, genre_id)"
                             "VALUES (?, ?)", (album_id, genre_id))
 
+    def del_genres(self, album_id):
+        """
+            Delete all genres for album
+            @parma album id as int
+            @warning: commit needed
+        """
+        with SqlCursor(Lp().db) as sql:
+            sql.execute("DELETE FROM album_genres "
+                        "WHERE album_id=?", (album_id,))
+
     def set_artist_ids(self, album_id, artist_ids):
         """
             Set artist id
@@ -102,7 +114,7 @@ class AlbumsDatabase:
         """
             Set album synced
             @param album id as int
-            @param synced as bool
+            @param synced as int
             @warning: commit needed
         """
         with SqlCursor(Lp().db) as sql:
@@ -177,7 +189,7 @@ class AlbumsDatabase:
             @return modification time as int
         """
         with SqlCursor(Lp().db) as sql:
-            result = sql.execute("SELECT synced FROM albums WHERE\
+            result = sql.execute("SELECT mtime FROM albums WHERE\
                                  rowid=?", (album_id,))
 
             v = result.fetchone()
@@ -373,7 +385,8 @@ class AlbumsDatabase:
             if path != "" and not os.path.exists(path):
                 tracks = self.get_track_ids(album_id, [], [])
                 if tracks:
-                    filepath = Lp().tracks.get_path(tracks[0])
+                    uri = Lp().tracks.get_uri(tracks[0])
+                    filepath = GLib.filename_from_uri(uri)[0]
                     path = os.path.dirname(filepath)
                     if os.path.exists(path):
                         sql.execute("UPDATE albums SET path=? "
@@ -399,8 +412,13 @@ class AlbumsDatabase:
             @return array of album ids as int
         """
         with SqlCursor(Lp().db) as sql:
-            result = sql.execute("SELECT rowid FROM albums WHERE popularity!=0\
-                                 ORDER BY popularity DESC LIMIT 100")
+            result = sql.execute("SELECT albums.rowid\
+                                  FROM albums, album_genres\
+                                  WHERE popularity!=0\
+                                  AND album_genres.genre_id!=?\
+                                  AND album_genres.album_id=albums.rowid\
+                                  ORDER BY popularity DESC LIMIT 100",
+                                 (Type.CHARTS,))
             return list(itertools.chain(*result))
 
     def get_recents(self):
@@ -409,8 +427,12 @@ class AlbumsDatabase:
             @return array of albums ids as int
         """
         with SqlCursor(Lp().db) as sql:
-            result = sql.execute("SELECT rowid FROM albums\
-                                  ORDER BY mtime DESC LIMIT 100")
+            result = sql.execute("SELECT albums.rowid\
+                                  FROM albums, album_genres\
+                                  WHERE album_genres.genre_id!=?\
+                                  AND album_genres.album_id=albums.rowid\
+                                  ORDER BY mtime DESC LIMIT 100",
+                                 (Type.CHARTS,))
             return list(itertools.chain(*result))
 
     def get_randoms(self):
@@ -421,8 +443,12 @@ class AlbumsDatabase:
         with SqlCursor(Lp().db) as sql:
             albums = []
 
-            result = sql.execute("SELECT rowid FROM albums\
-                                  ORDER BY random() LIMIT 100")
+            result = sql.execute("SELECT albums.rowid\
+                                  FROM albums, album_genres\
+                                  WHERE album_genres.genre_id!=?\
+                                  AND album_genres.album_id=albums.rowid\
+                                  ORDER BY random() LIMIT 100",
+                                 (Type.CHARTS,))
             albums = list(itertools.chain(*result))
             self._cached_randoms = list(albums)
             return albums
@@ -535,9 +561,9 @@ class AlbumsDatabase:
             result = sql.execute(request, filters)
             return list(itertools.chain(*result))
 
-    def get_track_paths(self, album_id, genre_ids, artist_ids):
+    def get_track_uris(self, album_id, genre_ids, artist_ids):
         """
-            Get track paths for album id/disc
+            Get track uris for album id/disc
             Will search track from albums from same artist
             with same name and different genre
             @param album id as int
@@ -553,7 +579,7 @@ class AlbumsDatabase:
             artist_ids = []
         with SqlCursor(Lp().db) as sql:
             filters = (album_id,)
-            request = "SELECT DISTINCT tracks.filepath\
+            request = "SELECT DISTINCT tracks.uri\
                        FROM tracks"
             if genre_ids:
                 request += ", track_genres"
@@ -627,7 +653,9 @@ class AlbumsDatabase:
         """
         genre_ids = remove_static_genres(genre_ids)
         orderby = Lp().settings.get_enum('orderby')
-        if orderby == OrderBy.ARTIST:
+        if genre_ids and genre_ids[0] == Type.CHARTS:
+            order = "ORDER BY albums.id DESC"
+        elif orderby == OrderBy.ARTIST:
             order = "ORDER BY artists.sortname\
                      COLLATE NOCASE COLLATE LOCALIZED,\
                      albums.year,\
@@ -649,15 +677,18 @@ class AlbumsDatabase:
             result = []
             # Get albums for all artists
             if not artist_ids and not genre_ids:
-                result = sql.execute(
-                                 "SELECT DISTINCT albums.rowid\
-                                  FROM albums, artists, album_artists\
-                                  WHERE artists.rowid=album_artists.artist_id\
-                                  AND albums.rowid=album_artists.album_id\
-                                  %s" % order)
+                filters = (Type.CHARTS,)
+                request = "SELECT DISTINCT albums.rowid\
+                           FROM albums, artists, album_artists, album_genres\
+                           WHERE artists.rowid=album_artists.artist_id\
+                           AND album_genres.genre_id!=?\
+                           AND album_genres.album_id=albums.rowid\
+                           AND albums.rowid=album_artists.album_id\
+                           %s" % order
+                result = sql.execute(request, filters)
             # Get albums for genre
             elif not artist_ids:
-                genres = tuple(genre_ids)
+                filters = tuple(genre_ids)
                 request = "SELECT DISTINCT albums.rowid FROM albums,\
                            album_genres, artists, album_artists\
                            WHERE artists.rowid=album_artists.artist_id\
@@ -666,18 +697,21 @@ class AlbumsDatabase:
                 for genre_id in genre_ids:
                     request += "album_genres.genre_id=? OR "
                 request += "1=0) %s" % order
-                result = sql.execute(request, genres)
+                result = sql.execute(request, filters)
             # Get albums for artist
             elif not genre_ids:
-                artists = tuple(artist_ids)
+                filters = (Type.CHARTS,)
+                filters += tuple(artist_ids)
                 request = "SELECT DISTINCT albums.rowid\
-                           FROM albums, artists, album_artists WHERE\
-                           artists.rowid=album_artists.artist_id AND\
-                           album_artists.album_id=albums.rowid AND ("
+                           FROM albums, artists, album_artists, album_genres\
+                           WHERE artists.rowid=album_artists.artist_id\
+                           AND album_genres.genre_id!=?\
+                           AND album_genres.album_id=albums.rowid\
+                           AND album_artists.album_id=albums.rowid AND ("
                 for artist_id in artist_ids:
                     request += "album_artists.artist_id=? OR "
                 request += "1=0) %s" % order
-                result = sql.execute(request, artists)
+                result = sql.execute(request, filters)
             # Get albums for artist id and genre id
             else:
                 filters = tuple(artist_ids)
@@ -754,6 +788,19 @@ class AlbumsDatabase:
                 return v[0]
             return 0
 
+    def get_genres(self, album_id):
+        """
+            Return genres for album
+        """
+        with SqlCursor(Lp().db) as sql:
+            result = sql.execute("SELECT genres.name\
+                                  FROM albums, album_genres, genres\
+                                  WHERE albums.rowid = ?\
+                                  AND album_genres.album_id = albums.rowid\
+                                  AND album_genres.genre_id = genres.rowid",
+                                 (album_id,))
+            return list(itertools.chain(*result))
+
     def search(self, string):
         """
             Search for albums looking like string
@@ -762,9 +809,12 @@ class AlbumsDatabase:
         """
         with SqlCursor(Lp().db) as sql:
             result = sql.execute("SELECT albums.rowid\
-                                  FROM albums\
+                                  FROM albums, album_genres\
                                   WHERE noaccents(name) LIKE ?\
-                                  LIMIT 25", ('%' + string + '%',))
+                                  AND album_genres.genre_id!=?\
+                                  AND album_genres.album_id=albums.rowid\
+                                  LIMIT 25", ('%' + noaccents(string) + '%',
+                                              Type.CHARTS))
             return list(itertools.chain(*result))
 
     def calculate_artist_ids(self, album_id):
@@ -794,7 +844,11 @@ class AlbumsDatabase:
             @return int
         """
         with SqlCursor(Lp().db) as sql:
-            result = sql.execute("SELECT COUNT(1) from albums")
+            result = sql.execute("SELECT COUNT(1)\
+                                  FROM albums, album_genres\
+                                  WHERE album_genres.genre_id!=?\
+                                  AND album_genres.album_id=albums.rowid",
+                                 (Type.CHARTS,))
             v = result.fetchone()
             if v is not None:
                 return v[0]
