@@ -15,7 +15,8 @@ from gettext import gettext as _
 import itertools
 
 from lollypop.sqlcursor import SqlCursor
-from lollypop.define import Lp
+from lollypop.define import Lp, Type
+from lollypop.utils import noaccents
 
 
 class TracksDatabase:
@@ -30,12 +31,12 @@ class TracksDatabase:
         """
         pass
 
-    def add(self, name, filepath, duration, tracknumber, discnumber, discname,
-            album_id, year, popularity, ltime, mtime):
+    def add(self, name, uri, duration, tracknumber, discnumber, discname,
+            album_id, year, popularity, ltime, mtime, persistent=1):
         """
             Add a new track to database
             @param name as string
-            @param filepath as string,
+            @param uri as string,
             @param duration as int
             @param tracknumber as int
             @param discnumber as int
@@ -46,25 +47,27 @@ class TracksDatabase:
             @param popularity as int
             @param ltime as int
             @param mtime as int
+            @param persistent as int
             @return inserted rowid as int
             @warning: commit needed
         """
         with SqlCursor(Lp().db) as sql:
             result = sql.execute(
-                "INSERT INTO tracks (name, filepath, duration, tracknumber,\
+                "INSERT INTO tracks (name, uri, duration, tracknumber,\
                 discnumber, discname, album_id,\
-                year, popularity, ltime, mtime) VALUES\
-                (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)", (name,
-                                                     filepath,
-                                                     duration,
-                                                     tracknumber,
-                                                     discnumber,
-                                                     discname,
-                                                     album_id,
-                                                     year,
-                                                     popularity,
-                                                     ltime,
-                                                     mtime))
+                year, popularity, ltime, mtime, persistent) VALUES\
+                (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)", (name,
+                                                        uri,
+                                                        duration,
+                                                        tracknumber,
+                                                        discnumber,
+                                                        discname,
+                                                        album_id,
+                                                        year,
+                                                        popularity,
+                                                        ltime,
+                                                        mtime,
+                                                        persistent))
             return result.lastrowid
 
     def add_artist(self, track_id, artist_id):
@@ -95,6 +98,16 @@ class TracksDatabase:
                             "track_genres (track_id, genre_id)"
                             "VALUES (?, ?)", (track_id, genre_id))
 
+    def del_genres(self, track_id):
+        """
+            Delete all genres for track
+            @parma album id as int
+            @warning: commit needed
+        """
+        with SqlCursor(Lp().db) as sql:
+            sql.execute("DELETE FROM track_genres "
+                        "WHERE track_id=?", (track_id,))
+
     def get_ids(self):
         """
             Return all tracks id
@@ -117,35 +130,23 @@ class TracksDatabase:
                                  (name,))
             return list(itertools.chain(*result))
 
-    def get_id_by_path(self, filepath):
+    def get_id_by_uri(self, uri):
         """
-            Return track id for path
-            @param filepath as str
+            Return track id for uri
+            @param uri as str
             @return track id as int
         """
         with SqlCursor(Lp().db) as sql:
-            result = sql.execute("SELECT rowid FROM tracks WHERE filepath=?",
-                                 (filepath,))
+            result = sql.execute("SELECT rowid FROM tracks WHERE uri=?",
+                                 (uri,))
             v = result.fetchone()
             if v is not None:
                 return v[0]
             return None
 
-    def get_ids_by_path(self, path):
-        """
-            Return track id for path
-            @param path as str
-            @return track id as int
-        """
-        with SqlCursor(Lp().db) as sql:
-            result = sql.execute("SELECT rowid FROM tracks\
-                                  WHERE filepath like ?",
-                                 ('%' + path + '%',))
-            return list(itertools.chain(*result))
-
     def get_id_by(self, name, album_id):
         """
-            Return track id for path
+            Return track id for uri
             @param name as str
             @param album id as int
             @return track id as int
@@ -188,20 +189,32 @@ class TracksDatabase:
                 return str(v[0])
             return ""
 
-    def get_path(self, track_id):
+    def get_uri(self, track_id):
         """
-            Get track path for track id
+            Get track uri for track id
             @param Track id as int
-            @return Path as string
+            @return uri as string
         """
         with SqlCursor(Lp().db) as sql:
-            result = sql.execute("SELECT filepath FROM tracks WHERE rowid=?",
+            result = sql.execute("SELECT uri FROM tracks WHERE rowid=?",
                                  (track_id,))
             v = result.fetchone()
             if v is not None:
                 return v[0]
             return ""
 
+    def set_uri(self, track_id, uri):
+        """
+            Set track uri
+            @param Track id as int
+            @param uri as string
+        """
+        with SqlCursor(Lp().db) as sql:
+            sql.execute("UPDATE tracks SET uri=?\
+                         WHERE rowid=?",
+                        (uri, track_id))
+            sql.commit()
+
     def get_album_id(self, track_id):
         """
             Get album id for track id
@@ -284,23 +297,23 @@ class TracksDatabase:
             Get mtime for tracks
             WARNING: Should be called before anything is shown on screen
             @param None
-            @return dict of {filepath as string: mtime as int}
+            @return dict of {uri as string: mtime as int}
         """
         with SqlCursor(Lp().db) as sql:
             mtimes = {}
-            result = sql.execute("SELECT filepath, mtime FROM tracks")
+            result = sql.execute("SELECT uri, mtime FROM tracks")
             for row in result:
                 mtimes.update((row,))
             return mtimes
 
-    def get_paths(self):
+    def get_uris(self):
         """
-            Get all tracks filepath
+            Get all tracks uri
             @param None
-            @return Array of filepath as string
+            @return Array of uri as string
         """
         with SqlCursor(Lp().db) as sql:
-            result = sql.execute("SELECT filepath FROM tracks;")
+            result = sql.execute("SELECT uri FROM tracks;")
             return list(itertools.chain(*result))
 
     def get_number(self, track_id):
@@ -345,6 +358,18 @@ class TracksDatabase:
                 return v[0]
             return 0
 
+    def set_duration(self, track_id, duration):
+        """
+            Get track duration for track id
+            @param Track id as int
+            @param duration as int
+        """
+        with SqlCursor(Lp().db) as sql:
+            sql.execute("UPDATE tracks\
+                         SET duration=?\
+                         WHERE rowid=?", (duration, track_id,))
+            sql.commit()
+
     def is_empty(self):
         """
             Return True if no tracks in db
@@ -454,6 +479,69 @@ class TracksDatabase:
                                   ORDER BY ltime DESC LIMIT 100")
             return list(itertools.chain(*result))
 
+    def get_persistent(self, track_id):
+        """
+            Return track persistent
+            @param track id as int
+            @return int
+        """
+        with SqlCursor(Lp().db) as sql:
+            result = sql.execute("SELECT rowid FROM tracks\
+                                  WHERE persistent=?", (track_id,))
+            v = result.fetchone()
+            if v is not None:
+                return v[0]
+            return 0
+
+    def set_persistent(self, track_id, persistent):
+        """
+            Set track persistent
+            @param track id as int
+            @param persistent as int
+        """
+        with SqlCursor(Lp().db) as sql:
+            sql.execute("UPDATE tracks\
+                         SET persistent=?\
+                         WHERE rowid=?", (persistent, track_id,))
+            sql.commit()
+
+    def get_non_persistent(self):
+        """
+            Return non persistent tracks
+            @return track ids as [int]
+        """
+        with SqlCursor(Lp().db) as sql:
+            # First tracks loaded by play on search
+            result = sql.execute("SELECT rowid FROM tracks\
+                                  WHERE persistent=0")
+            return list(itertools.chain(*result))
+
+    def get_old_from_charts(self, limit):
+        """
+            Return old tracks from charts
+            @param limit as int
+            @return track ids as [int]
+        """
+        with SqlCursor(Lp().db) as sql:
+            # Get charts album count
+            result = sql.execute("SELECT COUNT(DISTINCT(album_id))\
+                                  FROM tracks\
+                                  WHERE persistent=3")
+            v = result.fetchone()
+            count = v[0] if v is not None else 0
+            if count > limit:
+                diff = count - limit
+                result = sql.execute("SELECT DISTINCT(album_id)\
+                                      FROM tracks\
+                                      WHERE persistent=3 LIMIT %s" % diff)
+            v = result.fetchone()
+            album_id = v[0] if v is not None else None
+            if album_id is not None:
+                result = sql.execute("SELECT rowid FROM tracks\
+                                     WHERE album_id=?", (album_id,))
+                return list(itertools.chain(*result))
+            return []
+
     def get_randoms(self):
         """
             Return random tracks
@@ -512,7 +600,7 @@ class TracksDatabase:
         """
             Get modification time
             @param track id  as int
-            @return popularity as int
+            @return mtime as int
         """
         with SqlCursor(Lp().db) as sql:
             result = sql.execute("SELECT mtime FROM tracks WHERE\
@@ -522,13 +610,29 @@ class TracksDatabase:
                 return v[0]
             return 0
 
+    def set_mtime(self, track_id, mtime):
+        """
+            Get modification time
+            @param track id  as int
+            @param mtime as int
+        """
+        with SqlCursor(Lp().db) as sql:
+            sql.execute("UPDATE tracks\
+                         SET mtime=?\
+                         WHERE rowid=?", (mtime, track_id))
+            sql.commit()
+
     def count(self):
         """
             Count albums
             @return int
         """
         with SqlCursor(Lp().db) as sql:
-            result = sql.execute("SELECT COUNT(1) from tracks")
+            result = sql.execute("SELECT COUNT(1)\
+                                  FROM tracks, track_genres\
+                                  WHERE tracks.rowid = track_genres.track_id\
+                                  AND track_genres.genre_id!=?",
+                                 (Type.CHARTS,))
             v = result.fetchone()
             if v is not None:
                 return v[0]
@@ -555,7 +659,7 @@ class TracksDatabase:
         with SqlCursor(Lp().db) as sql:
             result = sql.execute("SELECT rowid, name FROM tracks\
                                   WHERE noaccents(name) LIKE ? LIMIT 25",
-                                 ('%' + searched + '%',))
+                                 ('%' + noaccents(searched) + '%',))
             return list(result)
 
     def search_track(self, artist, title):
