@@ -35,6 +35,8 @@ DataPath = path.expanduser("~") + "/.local/share/lollypop"
 
 Lp = Gio.Application.get_default
 
+GOOGLE_API_ID = "015987506728554693370:waw3yqru59a"
+
 
 # Represent what to do on next track
 class NextContext:
@@ -50,6 +52,13 @@ class SelectionMode:
     LIMITED = 1
 
 
+class DbPersistent:
+    NONE = 0
+    INTERNAL = 1
+    EXTERNAL = 2
+    CHARTS = 3
+
+
 class OpenLink:
     NONE = 0
     OPEN = 1
@@ -108,6 +117,11 @@ class OrderBy:
     POPULARITY = 3
 
 
+class ChartsProvider:
+    ITUNES = 0
+    SPOTIFY = 1
+
+
 # Order is important
 class Type:
     NONE = -1
@@ -118,7 +132,8 @@ class Type:
     RADIOS = -6
     EXTERNALS = -7
     SEARCH = -8
-    ALL = -9
+    CHARTS = -9
+    ALL = -10
     LOVED = -997
     NEVER = -998
     DEVICES = -1000
