@@ -56,23 +56,23 @@ class LastFM(LastFMNetwork):
             Init lastfm support
         """
         try:
-            self._settings = Gio.Settings.new('org.gnome.system.proxy.http')
+            self.__settings = Gio.Settings.new('org.gnome.system.proxy.http')
         except:
-            self._settings = None
-        self._username = ''
-        self._is_auth = False
-        self._password = None
-        self._check_for_proxy()
-        self._goa = self._get_goa_oauth()
-        if self._goa is not None:
-            self._API_KEY = self._goa.props.client_id
-            self._API_SECRET = self._goa.props.client_secret
+            self.__settings = None
+        self.__username = ''
+        self.__is_auth = False
+        self.__password = None
+        self.__check_for_proxy()
+        self.__goa = self.__get_goa_oauth()
+        if self.__goa is not None:
+            self.__API_KEY = self.__goa.props.client_id
+            self.__API_SECRET = self.__goa.props.client_secret
         else:
-            self._API_KEY = '7a9619a850ccf7377c46cf233c51e3c6'
-            self._API_SECRET = '9254319364d73bec6c59ace485a95c98'
+            self.__API_KEY = '7a9619a850ccf7377c46cf233c51e3c6'
+            self.__API_SECRET = '9254319364d73bec6c59ace485a95c98'
         LastFMNetwork.__init__(self,
-                               api_key=self._API_KEY,
-                               api_secret=self._API_SECRET)
+                               api_key=self.__API_KEY,
+                               api_secret=self.__API_SECRET)
         self.connect(None)
 
     def connect(self, password):
@@ -80,24 +80,24 @@ class LastFM(LastFMNetwork):
             Connect lastfm
             @param password as str/None
         """
-        if self._goa:
-            t = Thread(target=self._connect, args=('', '', True))
+        if self.__goa:
+            t = Thread(target=self.__connect, args=('', '', True))
             t.daemon = True
             t.start()
         # Get username/password from GSettings/Secret
         elif Secret is not None and\
                 Gio.NetworkMonitor.get_default().get_network_available():
-            self._username = Lp().settings.get_value(
+            self.__username = Lp().settings.get_value(
                                                    'lastfm-login').get_string()
             if password is None:
                 schema = Secret.Schema.new("org.gnome.Lollypop",
                                            Secret.SchemaFlags.NONE,
                                            SecretSchema)
                 Secret.password_lookup(schema, SecretAttributes, None,
-                                       self._on_password_lookup)
+                                       self.__on_password_lookup)
             else:
-                t = Thread(target=self._connect, args=(self._username,
-                                                       password, True))
+                t = Thread(target=self.__connect, args=(self.__username,
+                                                        password, True))
                 t.daemon = True
                 t.start()
 
@@ -107,10 +107,10 @@ class LastFM(LastFMNetwork):
             @param password as str
         """
         if Gio.NetworkMonitor.get_default().get_network_available():
-            self._username = Lp().settings.get_value(
+            self.__username = Lp().settings.get_value(
                                                    'lastfm-login').get_string()
-            self._connect(self._username, password)
-            t = Thread(target=self._populate_loved_tracks, args=(True,))
+            self.__connect(self.__username, password)
+            t = Thread(target=self.__populate_loved_tracks, args=(True,))
             t.daemon = True
             t.start()
 
@@ -142,8 +142,8 @@ class LastFM(LastFMNetwork):
             @param duration as int
         """
         if Gio.NetworkMonitor.get_default().get_network_available() and\
-           self._is_auth and Secret is not None:
-            t = Thread(target=self._scrobble,
+           self.__is_auth and Secret is not None:
+            t = Thread(target=self.__scrobble,
                        args=(artist,
                              album,
                              title,
@@ -161,8 +161,8 @@ class LastFM(LastFMNetwork):
             @param duration as int
         """
         if Gio.NetworkMonitor.get_default().get_network_available() and\
-           self._is_auth and Secret is not None:
-            t = Thread(target=self._now_playing,
+           self.__is_auth and Secret is not None:
+            t = Thread(target=self.__now_playing,
                        args=(artist,
                              album,
                              title,
@@ -179,7 +179,7 @@ class LastFM(LastFMNetwork):
         """
         # Love the track on lastfm
         if Gio.NetworkMonitor.get_default().get_network_available() and\
-           self._is_auth:
+           self.__is_auth:
             track = self.get_track(artist, title)
             try:
                 track.love()
@@ -195,7 +195,7 @@ class LastFM(LastFMNetwork):
         """
         # Love the track on lastfm
         if Gio.NetworkMonitor.get_default().get_network_available() and\
-           self._is_auth:
+           self.__is_auth:
             track = self.get_track(artist, title)
             try:
                 track.unlove()
@@ -207,19 +207,19 @@ class LastFM(LastFMNetwork):
         """
             True if valid authentication send
         """
-        return self._is_auth
+        return self.__is_auth
 
     @property
     def is_goa(self):
         """
             True if using Gnome Online Account
         """
-        return self._goa is not None
+        return self.__goa is not None
 
 #######################
 # PRIVATE             #
 #######################
-    def _get_goa_oauth(self):
+    def __get_goa_oauth(self):
         """
             Init Gnome Online Account
             @return get_oauth2_based()/None
@@ -233,52 +233,53 @@ class LastFM(LastFMNetwork):
             pass
         return None
 
-    def _check_for_proxy(self):
+    def __check_for_proxy(self):
         """
             Enable proxy if needed
         """
-        if self._settings is not None:
-            h = self._settings.get_value('host').get_string()
-            p = self._settings.get_value('port').get_int32()
+        if self.__settings is not None:
+            h = self.__settings.get_value('host').get_string()
+            p = self.__settings.get_value('port').get_int32()
             if h != '' and p != 0:
                 self.enable_proxy(host=h, port=p)
                 return
         self.disable_proxy()
 
-    def _connect(self, username, password, populate_loved=False):
+    def __connect(self, username, password, populate_loved=False):
         """
             Connect lastfm
             @param username as str
             @param password as str
             @thread safe
         """
-        self._username = username
-        if self._goa is not None or (password != '' and username != ''):
-            self._is_auth = True
+        self.__username = username
+        if self.__goa is not None or (password != '' and username != ''):
+            self.__is_auth = True
         else:
-            self._is_auth = False
+            self.__is_auth = False
         try:
-            self._check_for_proxy()
-            if self._goa is None:
+            self.__check_for_proxy()
+            if self.__goa is None:
                 LastFMNetwork.__init__(
                     self,
-                    api_key=self._API_KEY,
-                    api_secret=self._API_SECRET,
-                    username=self._username,
+                    api_key=self.__API_KEY,
+                    api_secret=self.__API_SECRET,
+                    username=self.__username,
                     password_hash=md5(password))
             else:
                 LastFMNetwork.__init__(
                     self,
-                    api_key=self._API_KEY,
-                    api_secret=self._API_SECRET,
-                    session_key=self._goa.call_get_access_token_sync(None)[0])
+                    api_key=self.__API_KEY,
+                    api_secret=self.__API_SECRET,
+                    session_key=self.__goa.call_get_access_token_sync(None)[0])
             if populate_loved:
-                self._populate_loved_tracks()
+                self.__populate_loved_tracks()
         except Exception as e:
-            debug("Lastfm::_connect(): %s" % e)
-            self._is_auth = False
+            debug("Lastfm::__connect(): %s" % e)
+            self.__is_auth = False
 
-    def _scrobble(self, artist, album, title, timestamp, duration, first=True):
+    def __scrobble(self, artist, album, title,
+                   timestamp, duration, first=True):
         """
             Scrobble track
             @param artist as str
@@ -289,11 +290,11 @@ class LastFM(LastFMNetwork):
             @param first is internal
             @thread safe
         """
-        debug("LastFM::_scrobble(): %s, %s, %s, %s, %s" % (artist,
-                                                           album,
-                                                           title,
-                                                           timestamp,
-                                                           duration))
+        debug("LastFM::__scrobble(): %s, %s, %s, %s, %s" % (artist,
+                                                            album,
+                                                            title,
+                                                            timestamp,
+                                                            duration))
         try:
             LastFMNetwork.scrobble(self,
                                    artist=artist,
@@ -306,9 +307,9 @@ class LastFM(LastFMNetwork):
             print("Lastfm::scrobble():", e)
             # Scrobble sometimes fails
             if first:
-                self._connect(self._username, self._password)
+                self.__connect(self.__username, self.__password)
 
-    def _now_playing(self, artist, album, title, duration, first=True):
+    def __now_playing(self, artist, album, title, duration, first=True):
         """
             Now playing track
             @param artist as str
@@ -324,10 +325,10 @@ class LastFM(LastFMNetwork):
                                              album=album,
                                              title=title,
                                              duration=duration)
-            debug("LastFM::_now_playing(): %s, %s, %s, %s" % (artist,
-                                                              album,
-                                                              title,
-                                                              duration))
+            debug("LastFM::__now_playing(): %s, %s, %s, %s" % (artist,
+                                                               album,
+                                                               title,
+                                                               duration))
         except BadAuthenticationError:
             if Lp().notify is not None:
                 GLib.idle_add(Lp().notify.send, _("Wrong Last.fm credentials"))
@@ -335,20 +336,20 @@ class LastFM(LastFMNetwork):
             print("Lastfm::scrobble():", e)
             # now playing sometimes fails
             if first:
-                self._connect(self._username, self._password)
-                self._now_playing(artist, album, title, duration, False)
+                self.__connect(self.__username, self.__password)
+                self.__now_playing(artist, album, title, duration, False)
 
-    def _populate_loved_tracks(self, force=False):
+    def __populate_loved_tracks(self, force=False):
         """
             Populate loved tracks playlist
             @param bool as force
         """
-        if not self._is_auth:
+        if not self.__is_auth:
             return
         try:
             if force or len(Lp().playlists.get_tracks(Type.LOVED)) == 0:
                 tracks = []
-                user = self.get_user(self._username)
+                user = self.get_user(self.__username)
                 for loved in user.get_loved_tracks():
                     track_id = Lp().tracks.search_track(
                                                       str(loved.track.artist),
@@ -357,9 +358,9 @@ class LastFM(LastFMNetwork):
                         tracks.append(Track(track_id))
                 Lp().playlists.add_tracks(Type.LOVED, tracks)
         except Exception as e:
-                print("LastFM::_populate_loved_tracks: %s" % e)
+                print("LastFM::__populate_loved_tracks: %s" % e)
 
-    def _on_password_lookup(self, source, result):
+    def __on_password_lookup(self, source, result):
         """
             Init self object
             @param source as GObject.Object
@@ -367,11 +368,11 @@ class LastFM(LastFMNetwork):
         """
         try:
             password = Secret.password_lookup_finish(result)
-            self._password = password
+            self.__password = password
             if Gio.NetworkMonitor.get_default().get_network_available():
-                t = Thread(target=self._connect,
-                           args=(self._username, password))
+                t = Thread(target=self.__connect,
+                           args=(self.__username, password))
                 t.daemon = True
                 t.start()
         except Exception as e:
-            print("Lastfm::_on_password_lookup(): %s" % e)
+            print("Lastfm::__on_password_lookup(): %s" % e)
