@@ -30,7 +30,9 @@ class BasePlayer(GObject.GObject):
         'lock-changed': (GObject.SignalFlags.RUN_FIRST, None, ()),
         'status-changed': (GObject.SignalFlags.RUN_FIRST, None, ()),
         'volume-changed': (GObject.SignalFlags.RUN_FIRST, None, ()),
+        'loading-changed': (GObject.SignalFlags.RUN_FIRST, None, ()),
         'queue-changed': (GObject.SignalFlags.RUN_FIRST, None, ()),
+        'duration-changed': (GObject.SignalFlags.RUN_FIRST, None, (int,)),
         'party-changed': (GObject.SignalFlags.RUN_FIRST, None, (bool,))
     }
 
