@@ -86,7 +86,9 @@ class MtpSync:
             self._fraction = 0.0
             plnames = []
 
-            if playlists[0] == Type.NONE:
+            GLib.idle_add(Lp().window.progress.set_fraction, 0, self)
+
+            if playlists and playlists[0] == Type.NONE:
                 # New tracks for synced albums
                 album_ids = Lp().albums.get_synced_ids()
                 for album_id in album_ids:
@@ -218,7 +220,6 @@ class MtpSync:
                     stream = m3u.open_readwrite(None)
                 except Exception as e:
                     print("DeviceWidget::_copy_to_device(): %s" % e)
-
             # Get tracks
             if playlist == Type.NONE:
                 track_ids = []
@@ -236,6 +237,8 @@ class MtpSync:
                     self.__in_thread = False
                     return
                 track = Track(track_id)
+                if not track.uri.startswith('file:'):
+                    continue
                 album_name = escape(track.album_name.lower())
                 if track.album.artist_ids[0] == Type.COMPILATIONS:
                     artists = escape(", ".join(track.artists).lower())
@@ -261,15 +264,16 @@ class MtpSync:
                                      (dst_art, Gio.FileCopyFlags.OVERWRITE,
                                       None, None))
 
-                track_name = escape(GLib.basename(track.path))
+                filepath = GLib.filename_from_uri(track.uri)[0]
+                track_name = escape(GLib.basename(filepath))
                 # Check extension, if not mp3, convert
-                ext = os.path.splitext(track.path)[1]
+                ext = os.path.splitext(filepath)[1]
                 if (ext != ".mp3" or self.__normalize) and self.__convert:
                     convertion_needed = True
                     track_name = track_name.replace(ext, ".mp3")
                 else:
                     convertion_needed = False
-                src_track = Gio.File.new_for_path(track.path)
+                src_track = Gio.File.new_for_uri(track.uri)
                 info = src_track.query_info('time::modified',
                                             Gio.FileQueryInfoFlags.NONE,
                                             None)
@@ -297,7 +301,7 @@ class MtpSync:
                             bus.add_signal_watch()
                             bus.connect('message::eos', self.__on_bus_eos)
                             self.__encoding = True
-                            while self.__encoding and self.__sync:
+                            while self.__encoding and self._syncing:
                                 sleep(1)
                             bus.disconnect_by_func(self.__on_bus_eos)
                             pipeline.set_state(Gst.State.PAUSED)
@@ -336,7 +340,7 @@ class MtpSync:
         track_ids = []
 
         # Get tracks
-        if playlists[0] == Type.NONE:
+        if playlists and playlists[0] == Type.NONE:
             track_ids = []
             album_ids = Lp().albums.get_synced_ids()
             for album_id in album_ids:
@@ -352,6 +356,8 @@ class MtpSync:
                 self.__in_thread = False
                 return
             track = Track(track_id)
+            if not track.uri.startswith('file:'):
+                continue
             album_name = escape(track.album_name.lower())
             if track.album.artist_ids[0] == Type.COMPILATIONS:
                 artists = escape(", ".join(track.artists).lower())
@@ -360,12 +366,13 @@ class MtpSync:
             album_uri = "%s/%s_%s" % (self._uri,
                                       artists,
                                       album_name)
-            track_name = escape(GLib.basename(track.path))
+            filepath = GLib.filename_from_uri(track.uri)[0]
+            track_name = escape(GLib.basename(filepath))
             # Check extension, if not mp3, convert
-            ext = os.path.splitext(track.path)[1]
+            ext = os.path.splitext(filepath)[1]
             if ext != ".mp3" and self.__convert:
                 track_name = track_name.replace(ext, ".mp3")
-            on_disk = Gio.File.new_for_path(track.path)
+            on_disk = Gio.File.new_for_path(filepath)
             info = on_disk.query_info('time::modified',
                                       Gio.FileQueryInfoFlags.NONE,
                                       None)
