@@ -14,6 +14,7 @@ from gi.repository import Gio
 
 from gettext import gettext as _
 from threading import Thread
+import unicodedata
 import os
 import socket
 import fcntl
@@ -23,6 +24,16 @@ from lollypop.define import Lp, Type
 from lollypop.objects import Track
 
 
+def noaccents(string):
+        """
+            Return string without accents
+            @param string as str
+            @return str
+        """
+        nfkd_form = unicodedata.normalize('NFKD', string)
+        return u"".join([c for c in nfkd_form if not unicodedata.combining(c)])
+
+
 def escape(str):
     """
         Escape string
@@ -163,7 +174,7 @@ def remove_static_genres(genre_ids):
         Remove static genre ids
         @param genre ids as [int]
     """
-    return [item for item in genre_ids if item >= 0]
+    return [item for item in genre_ids if item >= 0 or item == Type.CHARTS]
 
 
 def set_loved(track_id, loved):
