@@ -15,14 +15,13 @@ from gi.repository import Gtk, GLib, Gdk, GObject, Pango
 from cgi import escape
 from gettext import gettext as _
 
-from lollypop.define import Lp, ArtSize, NextContext
+from lollypop.define import Lp, ArtSize, NextContext, Type
 from lollypop.define import WindowSize, Shuffle, Loading
 from lollypop.widgets_track import TracksWidget, TrackRow
-from lollypop.objects import Track
+from lollypop.objects import Track, Album
 from lollypop.widgets_rating import RatingWidget
-from lollypop.pop_menu import AlbumMenu
+from lollypop.pop_menu import AlbumMenuPopover, AlbumMenu
 from lollypop.pop_artwork import CoversPopover
-from lollypop.objects import Album
 
 
 class AlbumWidget:
@@ -49,8 +48,8 @@ class AlbumWidget:
         self._overlay_orientation = Gtk.Orientation.HORIZONTAL
         self._squared_class = "squared-icon"
         self._rounded_class = "rounded-icon"
-        self._scan_signal = Lp().scanner.connect('album-update',
-                                                 self.__on_album_update)
+        self._scan_signal = Lp().scanner.connect('album-updated',
+                                                 self.__on_album_updated)
         self.connect('destroy', self.__on_destroy)
 
     def set_cover(self):
@@ -109,13 +108,21 @@ class AlbumWidget:
         """
         pass
 
+    def update_duration(self, track_id):
+        """
+            Update duration for current track
+            @param track id as int
+        """
+        pass
+
     def stop(self):
         """
             Stop populating
         """
         self._loading = Loading.STOP
 
-    def get_id(self):
+    @property
+    def id(self):
         """
             Return album id for widget
             @return album id as int
@@ -359,7 +366,7 @@ class AlbumWidget:
         if self._scan_signal is not None:
             Lp().scanner.disconnect(self._scan_signal)
 
-    def __on_album_update(self, scanner, album_id):
+    def __on_album_updated(self, scanner, album_id):
         """
             On album modified, disable it
             @param scanner as CollectionScanner
@@ -450,8 +457,12 @@ class AlbumSimpleWidget(Gtk.FlowBoxChild, AlbumWidget):
         self.show_all()
         self._widget.connect('enter-notify-event', self._on_enter_notify)
         self._widget.connect('leave-notify-event', self._on_leave_notify)
+        if self._album.is_youtube:
+            self._cover.get_style_context().add_class(
+                                                'cover-frame-youtube')
 
-    def get_id(self):
+    @property
+    def id(self):
         """
             Return album id
             @return int
@@ -717,6 +728,9 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget):
             self._menu.show()
         else:
             self.connect('map', self.__on_map)
+        if self._album.is_youtube and show_cover:
+            self._cover.get_style_context().add_class(
+                                                'cover-frame-youtube')
 
     def update_playing_indicator(self):
         """
@@ -728,6 +742,15 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget):
             self._tracks_right[disc.number].update_playing(
                 Lp().player.current_track.id)
 
+    def update_duration(self, track_id):
+        """
+            Update duration for current track
+            @param track id as int
+        """
+        for disc in self._album.discs:
+            self._tracks_left[disc.number].update_duration(track_id)
+            self._tracks_right[disc.number].update_duration(track_id)
+
     def populate(self):
         """
             Populate tracks
@@ -790,7 +813,7 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget):
         for dic in [self._tracks_left, self._tracks_right]:
             for widget in dic.values():
                 for child in widget.get_children():
-                    if child.get_id() == Lp().player.current_track.id:
+                    if child.id == Lp().player.current_track.id:
                         return child.translate_coordinates(parent, 0, 0)[1]
         return None
 
@@ -849,8 +872,16 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget):
             @param widget as Gtk.Button
             @param album id as int
         """
-        pop_menu = AlbumMenu(self._album)
-        popover = Gtk.Popover.new_from_model(self._menu, pop_menu)
+        if self._album.genre_ids and self._album.genre_ids[0] == Type.CHARTS:
+            popover = AlbumMenuPopover(self._album, None)
+            popover.set_relative_to(widget)
+            popover.set_position(Gtk.PositionType.BOTTOM)
+        elif self._album.is_youtube:
+            popover = AlbumMenuPopover(self._album, AlbumMenu(self._album))
+            popover.set_relative_to(widget)
+        else:
+            popover = Gtk.Popover.new_from_model(widget,
+                                                 AlbumMenu(self._album))
         popover.connect('closed', self.__on_pop_menu_closed)
         self.get_style_context().add_class('album-menu-selected')
         popover.show()
@@ -887,6 +918,16 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget):
         widget[disc_number].add(row)
         GLib.idle_add(self.__add_tracks, tracks, widget, disc_number, i + 1)
 
+    def __show_spinner(self, widget, track_id):
+        """
+            Show spinner for widget
+            @param widget as TracksWidget
+            @param track id as int
+        """
+        track = Track(track_id)
+        if track.is_youtube:
+            widget.show_spinner(track_id)
+
     def __on_map(self, widget):
         """
             Fix for Gtk < 3.18,
@@ -984,7 +1025,9 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget):
         # Play track with no album, force repeat on track
         elif self._button_state & Gdk.ModifierType.SHIFT_MASK:
             Lp().player.clear_albums()
-            Lp().player.load(Track(track_id))
+            self.__show_spinner(widget, track_id)
+            track = Track(track_id)
+            Lp().player.load(track)
         else:
             # Do not modify album list if in party mode
             if not Lp().player.is_party:
@@ -996,7 +1039,9 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget):
                 # Else, add album if missing
                 elif not Lp().player.has_album(self._album):
                     Lp().player.add_album(self._album)
-            Lp().player.load(Track(track_id))
+            self.__show_spinner(widget, track_id)
+            track = Track(track_id)
+            Lp().player.load(track)
             if self._button_state & Gdk.ModifierType.CONTROL_MASK:
                 Lp().player.set_next_context(NextContext.STOP_TRACK)
 
