@@ -72,7 +72,8 @@ class PlaylistsWidget(Gtk.Grid):
 
         self.add(self.__box)
 
-    def get_id(self):
+    @property
+    def id(self):
         """
             Return playlist widget id
             @return int
@@ -105,7 +106,7 @@ class PlaylistsWidget(Gtk.Grid):
         ordinate = None
         for child in self.__tracks_widget_left.get_children() + \
                 self.__tracks_widget_right.get_children():
-            if child.get_id() == Lp().player.current_track.id:
+            if child.id == Lp().player.current_track.id:
                 ordinate = child.translate_coordinates(self.__box, 0, 0)[1]
         return ordinate
 
@@ -151,6 +152,14 @@ class PlaylistsWidget(Gtk.Grid):
         self.__tracks_widget_left.update_playing(Lp().player.current_track.id)
         self.__tracks_widget_right.update_playing(Lp().player.current_track.id)
 
+    def update_duration(self, track_id):
+        """
+            Update duration for current track
+            @param track id as int
+        """
+        self.__tracks_widget_left.update_duration(track_id)
+        self.__tracks_widget_right.update_duration(track_id)
+
     def stop(self):
         """
             Stop loading
@@ -185,7 +194,7 @@ class PlaylistsWidget(Gtk.Grid):
             self.__update_tracks()
         else:
             for child in children:
-                if child.get_id() == track_id:
+                if child.id == track_id:
                     child.destroy()
                     break
             self.__update_tracks()
@@ -237,9 +246,9 @@ class PlaylistsWidget(Gtk.Grid):
         self.__tracks_left = []
         self.__tracks_right = []
         for child in self.__tracks_widget_left.get_children():
-            self.__tracks_left.append(child.get_id())
+            self.__tracks_left.append(child.id)
         for child in self.__tracks_widget_right.get_children():
-            self.__tracks_right.append(child.get_id())
+            self.__tracks_right.append(child.id)
 
     def __update_position(self):
         """
@@ -276,6 +285,16 @@ class PlaylistsWidget(Gtk.Grid):
                 prev_album_id = Track(self.__tracks_left[-1]).album.id
         self.__tracks_widget_right.update_headers(prev_album_id)
 
+    def __show_spinner(self, widget, track_id):
+        """
+            Show spinner for widget
+            @param widget as TracksWidget
+            @param track id as int
+        """
+        track = Track(track_id)
+        if track.is_youtube:
+            widget.show_spinner(track_id)
+
     def __move_track(self, dst, src, up):
         """
             Move track from src to row
@@ -303,7 +322,7 @@ class PlaylistsWidget(Gtk.Grid):
             return
         # Remove src from src_widget
         for child in src_widget.get_children():
-            if child.get_id() == src:
+            if child.id == src:
                 child.destroy()
                 break
         src_track = Track(src)
@@ -313,7 +332,7 @@ class PlaylistsWidget(Gtk.Grid):
         # Get previous track
         if dst != -1:
             for child in dst_widget.get_children():
-                if child.get_id() == dst:
+                if child.id == dst:
                     break
                 index += 1
             if not up:
@@ -356,7 +375,7 @@ class PlaylistsWidget(Gtk.Grid):
                 child = self.__tracks_widget_right.get_children()[-1]
             except:
                 child = self.__tracks_widget_left.get_children()[-1]
-            self.__on_track_moved(widget, child.get_id(),
+            self.__on_track_moved(widget, child.id,
                                   int(data.get_text()), False)
         except:
             pass
@@ -436,6 +455,7 @@ class PlaylistsWidget(Gtk.Grid):
             else:
                 Lp().player.append_to_queue(track_id)
         else:
+            self.__show_spinner(widget, track_id)
             Lp().player.load(Track(track_id))
             if not Lp().player.is_party:
                 Lp().player.populate_user_playlist_by_tracks(
